# Description
Elrond Python Command Line Tools and SDK for interacting with the Elrond Network (in general) and Smart Contracts (in particular). 

## Documentation
[docs.elrond.com](https://docs.elrond.com/sdk-and-tools/erdpy/erdpy/)

[pkg.go.dev](https://pkg.go.dev/github.com/ElrondNetwork/elrond-sdk/erdgo)

## CLI
[CLI](CLI.md)

## Distribution
[erdpy-up](https://docs.elrond.com/sdk-and-tools/erdpy/installing-erdpy/) and [PyPi](https://pypi.org/project/erdpy/#history)

## CHANGELOG
[CHANGELOG](CHANGELOG.md)
